struct s
(
	tTooltip = "Dublicate Objects with same transforms, bounding box, number of vertices.",
	
	fn isValid obj =
	(
		local nVerts = try obj.mesh.verts.count catch 0
		
		superclassof obj == geometryclass and
		obj.layer.on and
		nVerts > 0
	),
	
	fn getObjFingerprint obj &t =
	(
		t = obj.transform as string +";"+ obj.min as string +";"+ obj.max as string +";"+ classof obj as string +";"+ obj.modifiers.count as string
	),
	
	fn count =
	(
		local l = for obj in geometry where isValid obj collect
		(
			local t = ""
			getObjFingerprint obj &t
		)
		l.count - (makeuniquearray l).count
	),
	
	fn clean =
	(
		local lOrig = for obj in geometry where isValid obj collect
		(
			local t = ""
			getObjFingerprint obj &t
		)
		local lUniq = makeuniquearray lOrig
		local lDiff = #()
		local nOrigStart = 0
		
		-- add empty end to array to cap it
		append lOrig ""
		append lUniq ""
		
		for nUniq=1 to lUniq.count do
		(
			local bSame = false
			nOrigStart += 1
			
			for nOrig=nOrigStart to lOrig.count while not bSame do
			(
				bSame = lUniq[nUniq] == lOrig[nOrig]
				
				if nOrig > nOrigStart then nOrigStart = nOrig
				
				if not bSame then
				(			
					append lDiff lOrig[nOrig]
				)
			)
		)
		
		local lObjs = #()
		for obj in geometry do
		(
			local t = ""
			getObjFingerprint obj &t
			local nMatch = finditem lDiff t
			if nMatch != 0 then
			(
				deleteitem lDiff nMatch
				append lObjs obj
			)
		)
		
		delete lObjs
	),
	
	fn selectObjects =
	(
		local lOrig = for obj in geometry where isValid obj collect
		(
			local t = ""
			getObjFingerprint obj &t
		)
		local lUniq = makeuniquearray lOrig
		local lDiff = #()
		local nOrigStart = 0
		
		-- add empty end to array to cap it
		append lOrig ""
		append lUniq ""
		
		for nUniq=1 to lUniq.count do
		(
			local bSame = false
			nOrigStart += 1
			
			for nOrig=nOrigStart to lOrig.count while not bSame do
			(
				bSame = lUniq[nUniq] == lOrig[nOrig]
				
				if nOrig > nOrigStart then nOrigStart = nOrig
				
				if not bSame then
				(			
					append lDiff lOrig[nOrig]
				)
			)
		)
		
		local lObjs = #()
		for obj in geometry do
		(
			local t = ""
			getObjFingerprint obj &t
			local nMatch = finditem lDiff t
			if nMatch != 0 then
			(
				deleteitem lDiff nMatch
				append lObjs obj
			)
		)
		
		select lObjs
		local bRefreshSel = false
		for obj in selection do
		(
			if isGroupHead obj and not isOpenGroupHead obj then
			(
				bRefreshSel = true
				setGroupOpen obj true
			)
		)
		if bRefreshSel then select lObjs
	)
)

